==> sonar-plugin-api-4.5.4-sources.jar: org/sonar/api/batch/events/InitializersPhaseHandler.java <==
/*
 * SonarQube, open source software quality management tool.
 * Copyright (C) 2008-2014 SonarSource
 * mailto:contact AT sonarsource DOT com
 *
 * SonarQube is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * SonarQube is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.api.batch.events;

import org.sonar.api.batch.Initializer;

import java.util.List;

/**
 * @since 3.7
 */
public interface InitializersPhaseHandler extends EventHandler {

  /**
   * This interface is not intended to be implemented by clients.
   */
  interface InitializersPhaseEvent {

    /**
     * @return list of Initializers in the order of execution
     */
    List<Initializer> getInitializers();

    boolean isStart();

    boolean isEnd();

  }

  /**
   * Called before and after execution of all {@link Initializers}s.
   */
  void onInitializersPhase(InitializersPhaseEvent event);

}

==> sonar-plugin-api-6.7.2-sources.jar: org/sonar/api/batch/events/InitializersPhaseHandler.java <==
/*
 * SonarQube
 * Copyright (C) 2009-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.api.batch.events;

import java.util.List;
import org.sonar.api.batch.Initializer;

/**
 * @since 3.7
 * @deprecated since 6.0
 */
@Deprecated
@FunctionalInterface
public interface InitializersPhaseHandler extends EventHandler {

  /**
   * This interface is not intended to be implemented by clients.
   */
  interface InitializersPhaseEvent {

    /**
     * @return list of Initializers in the order of execution
     */
    List<Initializer> getInitializers();

    boolean isStart();

    boolean isEnd();

  }

  /**
   * Called before and after execution of all {@link Initializer}s.
   */
  void onInitializersPhase(InitializersPhaseEvent event);

}
